@@ -1,4 +1,4 @@
-/* GDM - The Gnome Display Manager
+/* GDM - The GNOME Display Manager
  * Copyright (C) 2003 Red Hat, Inc.
  * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  * Copyright (C) Rik Faith <faith@precisioninsight.com>
@@ -35,7 +35,7 @@
 #include <fcntl.h>
 #include <sys/time.h>
 #include <unistd.h>
-#include <libgnome/libgnome.h>
+#include <vicious.h>
 
 #include "gdm.h"
 #include "md5.h"
@@ -69,7 +69,9 @@ struct rngs {
    { "/dev/audio",    MAXBUFFERSIZE,	0 },
    { "/etc/shadow",   MAXBUFFERSIZE,	0 },
    { "/var/log/messages",   MAXBUFFERSIZE,	0 },
+   /*
    { "/var/spool/mail/root", MAXBUFFERSIZE,	0 },
+   */
 };
 
 #define RNGS (sizeof(rngs)/sizeof(struct rngs))
@@ -77,7 +79,32 @@ struct rngs {
 /* Some semi random spinners to spin,
  * this is 20 bytes of semi random data */
 #define RANDNUMS 5
-static int randnums[RANDNUMS];
+static guint32 randnums[RANDNUMS];
+
+/* stolen from XDM which in turn stole this
+   from the C standard */
+static guint32
+next_rand_15 (guint32 num)
+{
+	num = num * 1103515245 + 12345;
+	return (unsigned int)(num/65536) % 32768;
+}
+
+/* really quite apparently only 31 bits of entropy result (from tests),
+   but oh well */
+static guint32
+next_rand_32 (guint32 num)
+{
+	int i;
+	guint32 ret;
+	guint8 *p = (guint8 *)&ret;
+
+	for (i = 0; i < 4; i++)  {
+		num = next_rand_15 (num);
+		p[i] = (num & 0xff00) >> 8;
+	}
+	return ret;
+}
 
 /* This adds a little bit of entropy to our buffer,
    just in case /dev/random doesn't work out for us
@@ -88,22 +115,31 @@ gdm_random_tick (void)
 {
 	struct timeval tv;
 	struct timezone tz;
-	static GRand *rnd = NULL;
 
 	gettimeofday (&tv, &tz);
 
-	if G_UNLIKELY (rnd == NULL)
-		rnd = g_rand_new_with_seed (tv.tv_usec ^ tv.tv_sec);
-	else
-		g_rand_set_seed (rnd, tv.tv_usec ^ tv.tv_sec);
-	randnums[0] ^= g_rand_int (rnd);
-	randnums[1] ^= g_random_int ();
-	randnums[2] ^= rand ();
-	randnums[3] ^= random ();
+	/* the higher order bits of the seconds
+	   are quite uninteresting */
+	randnums[0] ^= next_rand_32 ((tv.tv_sec << 20) ^ tv.tv_usec);
 
-	/* a little bit of dependence on speed of execution */
-	gettimeofday (&tv, &tz);
-	randnums[4] ^= (tv.tv_usec ^ randnums[3]);
+	/* different method of combining */
+	randnums[1] ^= next_rand_32 (tv.tv_sec) ^ next_rand_32 (tv.tv_usec);
+
+	/* probably unneeded, but just being anal */
+	randnums[2] ^= (tv.tv_sec << 20) ^ tv.tv_usec;
+
+	/* probably unneeded, to guess above
+	   the number of invocation is likely needed
+	   anyway */
+	randnums[3] ++;
+
+	/* also hope that other places call
+	   g_random_int.  Note that on systems
+	   without /dev/urandom, this will yet again
+	   measure time the first time it's called and
+	   we'll add entropy based on the speed of the
+	   computer.  Yay */
+	randnums[4] ^= g_random_int ();
 }
 
 /* check a few values and if we get the same
@@ -153,7 +189,7 @@ gdm_cookie_generate (GdmDisplay *d)
     gdm_md5_update (&ctx, old_cookie, 16);
 
     /* use some uninitialized stack space */
-    gdm_md5_update (&ctx, digest, 16);
+    gdm_md5_update (&ctx, (unsigned char *) cookie, sizeof (cookie));
 
     pid = getppid();
     gdm_md5_update (&ctx, (unsigned char *) &pid, sizeof (pid));
@@ -166,14 +202,17 @@ gdm_cookie_generate (GdmDisplay *d)
 	    file = d->authfile;
 	if G_UNLIKELY (file == NULL)
 	    continue;
-	fd = open (file, O_RDONLY|O_NONBLOCK
+	do {
+		errno = 0;
+		fd = open (file, O_RDONLY|O_NONBLOCK
 #ifdef O_NOCTTY
-			|O_NOCTTY
+			   |O_NOCTTY
 #endif
 #ifdef O_NOFOLLOW
-			|O_NOFOLLOW
+			   |O_NOFOLLOW
 #endif
-		   );
+			  );
+	} while G_UNLIKELY (errno == EINTR);
 	if G_LIKELY (fd >= 0) {
 	    /* Apparently this can sometimes block anyway even if it is O_NONBLOCK,
 	       so use select to figure out if there is something available */
@@ -191,7 +230,7 @@ gdm_cookie_generate (GdmDisplay *d)
 		lseek (fd, rngs[i].seek, SEEK_SET);
 
 	    if G_LIKELY (select (fd+1, &rfds, NULL, NULL, &tv) > 0) {
-	        IGNORE_EINTR (r = read (fd, buf, MIN (sizeof (buf), rngs[i].length)));
+	        VE_IGNORE_EINTR (r = read (fd, buf, MIN (sizeof (buf), rngs[i].length)));
 	    }
 
 	    if G_LIKELY (r > 0)
@@ -199,10 +238,10 @@ gdm_cookie_generate (GdmDisplay *d)
 	    else
 		r = 0;
 
-	    IGNORE_EINTR (close (fd));
+	    VE_IGNORE_EINTR (close (fd));
 
 	    if G_LIKELY (r >= rngs[i].length &&
-		data_seems_random (buf, r)) 
+			 data_seems_random ((char *) buf, r)) 
 		break;
 	}
     }
