@@ -1,3 +1,21 @@
+/* GDM - The GNOME Display Manager
+ * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
 #include "config.h"
 
 #include <vicious.h>
@@ -18,16 +36,15 @@
 extern int GdmFirstVT;
 extern gboolean GdmVTAllocation;
 
-#if defined (__linux__) || defined (__FreeBSD__) || defined(__DragonFly__)
+/* Virtual terminals only supported on Linux, FreeBSD, or DragonFly */
+
+#if defined (__linux__) || defined (__FreeBSD__) || defined (__DragonFly__)
 
 #ifdef __linux__
 #include <sys/vt.h>
-#endif
-#if defined(__FreeBSD__) || defined(__DragonFly__)
+#elif defined(__FreeBSD__) || defined(__DragonFly__)
 #include <sys/consio.h>
-#endif
 
-#if defined( __FreeBSD__) || defined(__DragonFly__)
 static const char*
 __itovty(int val)
 {
@@ -66,8 +83,10 @@ open_vt (int vtno)
 	return fd;
 }
 
+#if defined (__linux__)
+
 static int 
-get_free_vt (int *vtfd)
+get_free_vt_linux (int *vtfd)
 {
 	int fd, fdv;
 	int vtno;
@@ -92,7 +111,7 @@ get_free_vt (int *vtfd)
 		return -1;
 	}
 
-	for (vtno = GdmFirstVT, vtmask = 1 << (vtno-1);
+	for (vtno = GdmFirstVT, vtmask = 1 << vtno;
 			vtstat.v_state & vtmask; vtno++, vtmask <<= 1);
 	if (!vtmask) {
 		VE_IGNORE_EINTR (close (fd));
@@ -108,6 +127,72 @@ get_free_vt (int *vtfd)
 	return vtno;
 }
 
+#elif defined (__FreeBSD__) || defined(__DragonFly__)
+
+static int
+get_free_vt_freebsd_dragonfly (int *vtfd)
+{
+	int fd, fdv;
+	int vtno;
+	GList *to_close_vts = NULL, *li;
+
+	*vtfd = -1;
+
+	do {
+		errno = 0;
+		fd = open ("/dev/console", O_WRONLY
+#ifdef O_NOCTTY
+			   |O_NOCTTY
+#endif
+			   , 0);
+	} while G_UNLIKELY (errno == EINTR);
+	if (fd < 0)
+		return -1;
+
+	if ((ioctl(fd, VT_OPENQRY, &vtno) < 0) || (vtno == -1)) {
+		VE_IGNORE_EINTR (close (fd));
+		return -1;
+	}
+
+	fdv = open_vt (vtno);
+	if (fdv < 0) {
+		VE_IGNORE_EINTR (close (fd));
+		return -1;
+	}
+
+	while (vtno < GdmFirstVT) {
+		int oldvt = vtno;
+		to_close_vts = g_list_prepend (to_close_vts,
+					       GINT_TO_POINTER (fdv));
+
+		if (ioctl(fd, VT_OPENQRY, &vtno) == -1) {
+			vtno = -1;
+			goto cleanup;
+		}
+
+		if (oldvt == vtno) {
+			vtno = -1;
+			goto cleanup;
+		}
+
+		fdv = open_vt (vtno);
+		if (fdv < 0) {
+			vtno = -1;
+			goto cleanup;
+		}
+	}
+
+	*vtfd = fdv;
+
+cleanup:
+	for (li = to_close_vts; li != NULL; li = li->next) {
+		VE_IGNORE_EINTR (close (GPOINTER_TO_INT (li->data)));
+	}
+	return vtno;
+}
+
+#endif
+
 char *
 gdm_get_empty_vt_argument (int *fd, int *vt)
 {
@@ -116,7 +201,12 @@ gdm_get_empty_vt_argument (int *fd, int *vt)
 		return NULL;
 	}
 
-	*vt = get_free_vt (fd);
+#if defined(__linux__)
+	*vt = get_free_vt_linux (fd);
+#elif defined(__FreeBSD__) || defined(__DragonFly__)
+	*vt = get_free_vt_freebsd_dragonfly (fd);
+#endif
+
 	if (*vt < 0)
 		return NULL;
 	else
