@@ -33,8 +33,7 @@ gboolean	gdm_xdmcp_init	(void);
 void		gdm_xdmcp_run	(void);
 void		gdm_xdmcp_close	(void);
 
-gboolean	gdm_xdmcp_is_loopback_addr (struct in_addr *ia);
-gboolean	gdm_xdmcp_is_local_addr (struct in_addr *ia);
+void gdm_xdmcp_migrate (GdmDisplay *from, GdmDisplay *to);
 
 #ifdef HAVE_LIBXDMCP
 /* Fix broken X includes */
