@@ -25,6 +25,7 @@
 /* For clist */
 #undef GTK_DISABLE_DEPRECATED
 
+#include <stdlib.h>
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 
@@ -113,7 +114,7 @@ glade_helper_load_widget (const char *file, const char *widget,
 	    ! G_TYPE_CHECK_INSTANCE_TYPE (w, expected_type)) {
 		glade_helper_bad_interface (xml->filename != NULL ?
 					      xml->filename :
-					      _("(memory buffer"),
+					      _("(memory buffer)"),
 					    widget,
 					    expected_type);
 		exit (1);
@@ -135,7 +136,7 @@ glade_helper_get (GladeXML *xml, const char *widget, GType expected_type)
 	    ! G_TYPE_CHECK_INSTANCE_TYPE (w, expected_type)) {
 		glade_helper_bad_interface (xml->filename != NULL ?
 					      xml->filename :
-					      _("(memory buffer"),
+					      _("(memory buffer)"),
 					    widget,
 					    expected_type);
 		exit (1);
@@ -155,7 +156,7 @@ glade_helper_get_clist (GladeXML *xml, const char *widget,
 	if (GTK_CLIST (w)->columns != expected_columns) {
 		glade_helper_bad_columns (xml->filename != NULL ?
 					    xml->filename :
-					    _("(memory buffer"),
+					    _("(memory buffer)"),
 					  widget,
 					  expected_type,
 					  expected_columns);
@@ -192,7 +193,7 @@ glade_helper_bad_interface (const char *filename, const char *widget,
 				 GTK_BUTTONS_OK,
 				 FALSE /* markup */,
 				 _("Cannot load user interface"),
-				 _("An error occured while loading the user "
+				 _("An error occurred while loading user "
 				   "interface element %s%s from file %s.  "
 				   "Possibly the glade interface description was "
 				   "corrupted.  "
@@ -245,7 +246,7 @@ glade_helper_bad_columns (const char *filename, const char *widget,
 				 GTK_BUTTONS_OK,
 				 FALSE /* markup */,
 				 _("Cannot load user interface"),
-				 ngettext ("An error occured while loading the "
+				 ngettext ("An error occurred while loading the "
 					   "user interface element %s%s from "
 					   "file %s. CList type widget should "
 					   "have %d column. Possibly the glade "
@@ -254,7 +255,7 @@ glade_helper_bad_columns (const char *filename, const char *widget,
 					   "will exit now. You should check "
 					   "your installation of %s or "
 					   "reinstall %s.",
-					   "An error occured while loading the "
+					   "An error occurred while loading the "
 					   "user interface element %s%s from "
 					   "file %s. CList type widget should "
 					   "have %d columns. Possibly the "
@@ -299,7 +300,7 @@ glade_helper_no_interface (const char *filename)
 				 GTK_BUTTONS_OK,
 				 FALSE /* markup */,
 				 _("Cannot load user interface"),
-				 _("An error occured while loading the user "
+				 _("An error occurred while loading the user "
 				   "interface from file %s.  "
 				   "Possibly the glade interface description was "
 				   "not found.  "
@@ -311,7 +312,7 @@ glade_helper_no_interface (const char *filename)
 				 PACKAGE,
 				 PACKAGE);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dlg), FALSE);
-	g_warning (_("No interface could be loaded, BAD! (file: %s)"),
+	g_warning (_("No interface could be loaded. This is BAD! (file: %s)"),
 		   tmp);
 
 	g_free (tmp);
