@@ -22,8 +22,13 @@
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <libgnome/libgnome.h>
+#include <locale.h>
 
+#ifdef HAVE_CRT_EXTERNS_H
+#include <crt_externs.h>
+#endif
+
+#include "ve-i18n.h"
 #include "ve-misc.h"
 
 char **
@@ -246,72 +251,6 @@ ve_find_file_simple (const char *filename, const GList *directories)
 	return NULL;
 }
 
-char *
-ve_find_file (const char *filename, const GList *directories)
-{
-	char *s, *ss;
-	const char *path;
-	char **pathv;
-	int i;
-
-	s = ve_find_file_simple (filename, directories);
-	if (s != NULL)
-		return s;
-	/* if the filename was NULL or absolute
-	 * no further checks are made */
-	if (filename == NULL ||
-	    g_path_is_absolute (filename))
-		return NULL;
-
-	s = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
-				       filename, TRUE, NULL);
-	if (s != NULL)
-		return s;
-
-	ss = g_build_filename (g_get_prgname (), filename, NULL);
-	s = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
-				       ss, TRUE, NULL);
-	g_free (ss);
-	if (s != NULL)
-		return s;
-
-	s = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_DATADIR,
-				       filename, TRUE, NULL);
-	if (s != NULL)
-		return s;
-
-	ss = g_build_filename (g_get_prgname (), filename, NULL);
-	s = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_DATADIR,
-				       ss, TRUE, NULL);
-	g_free (ss);
-	if (s != NULL)
-		return s;
-
-	path = g_getenv ("GNOME_PATH");
-	if (path != NULL) {
-		pathv = g_strsplit (path, ":", 0);
-		for (i = 0; pathv[i] != NULL; i++) {
-			s = g_build_filename (pathv[i], "share", filename, NULL);
-			if (access (s, F_OK) == 0) {
-				g_strfreev (pathv);
-				return s;
-			}
-			g_free (s);
-			s = g_build_filename (pathv[i], "share",
-					      g_get_prgname (),
-					      filename, NULL);
-			if (access (s, F_OK) == 0) {
-				g_strfreev (pathv);
-				return s;
-			}
-			g_free (s);
-		}
-		g_strfreev (pathv);
-	}
-
-	return NULL;
-}
-
 char *
 ve_locale_to_utf8 (const char *str)
 {
@@ -336,6 +275,30 @@ ve_locale_from_utf8 (const char *str)
 	}
 }
 
+char *
+ve_filename_to_utf8 (const char *str)
+{
+	char *ret = g_filename_to_utf8 (str, -1, NULL, NULL, NULL);
+	if (ret == NULL) {
+		g_warning ("string not in proper locale encoding: \"%s\"", str);
+		return g_strdup (str);
+	} else {
+		return ret;
+	}
+}
+
+char *
+ve_filename_from_utf8 (const char *str)
+{
+	char *ret = g_filename_from_utf8 (str, -1, NULL, NULL, NULL);
+	if (ret == NULL) {
+		g_warning ("string not in proper utf8 encoding: \"%s\"", str);
+		return g_strdup (str);
+	} else {
+		return ret;
+	}
+}
+
 char *
 ve_strftime (struct tm *the_tm, const char *format)
 {
@@ -372,7 +335,7 @@ gboolean
 ve_locale_exists (const char *loc)
 {
 	gboolean ret;
-	char *old = g_strdup (setlocale (LC_ALL, NULL));
+	char *old = g_strdup (setlocale (LC_MESSAGES, NULL));
 	if (setlocale (LC_MESSAGES, loc) != NULL)
 		ret = TRUE;
 	else
@@ -381,3 +344,164 @@ ve_locale_exists (const char *loc)
 	g_free (old);
 	return ret;
 }
+
+/**
+ * ve_setenv:
+ * @name: An environment variable name.
+ * @value: The value to assign to the environment variable.
+ * @overwrite: If %TRUE, overwrite the existing @name variable in the
+ * environment.
+ * 
+ * Adds "@name=@value" to the environment. Note that on systems without setenv,
+ * this leaks memory so please do not use inside a loop or anything like that.
+ * The semantics are the same as the glibc setenv() (if setenv() exists, it is
+ * used).
+ *
+ * If @overwrite is %FALSE and the variable already exists in the environment,
+ * then %0 is returned and the value is not changed.
+ *
+ * Returns: %0 on success, %-1 on error
+ * 
+ **/
+#if ! GLIB_CHECK_VERSION(2,3,1)
+int
+ve_setenv (const char *name, const char *value, gboolean overwrite)
+{
+#if defined (HAVE_SETENV)
+	return setenv (name, value != NULL ? value : "", overwrite);
+#else
+	char *string;
+	
+	if (! overwrite && g_getenv (name) != NULL) {
+		return 0;
+	}
+	
+	/* This results in a leak when you overwrite existing
+	 * settings. It would be fairly easy to fix this by keeping
+	 * our own parallel array or hash table.
+	 */
+	string = g_strconcat (name, "=", value, NULL);
+	return putenv (string);
+#endif
+}
+#endif
+
+/**
+ * ve_unsetenv:
+ * @name: The environment variable to unset.
+ * 
+ * Description: Removes @name from the environment.
+ * In case there is no native implementation of unsetenv,
+ * this could cause leaks depending on the implementation of
+ * environment.
+ * 
+ **/
+#if ! GLIB_CHECK_VERSION(2,3,1)
+void
+ve_unsetenv (const char *name)
+{
+#if defined (HAVE_SETENV)
+	unsetenv (name);
+#else
+
+#ifdef HAVE__NSGETENVIRON
+#define environ (*_NSGetEnviron())
+#else
+	extern char **environ;
+#endif
+	int i, len;
+
+	if (environ == NULL)
+		return;
+
+	len = strlen (name);
+	
+	/* Mess directly with the environ array.
+	 * This seems to be the only portable way to do this.
+	 */
+	for (i = 0; environ[i] != NULL; i++) {
+		if (strncmp (environ[i], name, len) == 0
+		    && environ[i][len + 1] == '=') {
+			break;
+		}
+	}
+	while (environ[i] != NULL) {
+		environ[i] = environ[i + 1];
+		i++;
+	}
+#endif
+}
+#endif
+
+/**
+ * ve_clearenv:
+ * 
+ * Description: Clears out the environment completely.
+ * In case there is no native implementation of clearenv,
+ * this could cause leaks depending on the implementation
+ * of environment.
+ * 
+ **/
+void
+ve_clearenv (void)
+{
+#ifdef HAVE_CLEARENV
+	clearenv ();
+#else
+
+#ifdef HAVE__NSGETENVIRON
+#define environ (*_NSGetEnviron())
+#else
+	extern char **environ;
+#endif
+	if (environ != NULL)
+		environ[0] = NULL;
+#endif
+}
+
+char *
+ve_find_prog_in_path (const char *prog, const char *path)
+{
+	char **vec;
+	int i;
+
+	if (ve_string_empty (prog) || ve_string_empty (path))
+		return NULL;
+
+	vec = g_strsplit (path, ":", -1);
+	for (i = 0; vec != NULL && vec[i] != NULL; i++) {
+		char *full = g_build_filename (vec[i], prog, NULL);
+		/* Do not use X_OK, we may be looking for things
+		   that are not executables */
+		if (access (full, F_OK) == 0) {
+			return full;
+		}
+		g_free (full);
+	}
+	return NULL;
+}
+
+gboolean
+ve_is_prog_in_path (const char *prog, const char *path)
+{
+	char *full = ve_find_prog_in_path (prog, path);
+	if (full != NULL) {
+		g_free (full);
+		return TRUE;
+	} else {
+		return FALSE;
+	}
+}
+
+char *
+ve_shell_quote_filename (const char *name)
+{
+	if (name[0] != '-') {
+		return g_shell_quote (name);
+	} else {
+		char *fname = g_strconcat ("./", name, NULL);
+		char *quoted = g_shell_quote (fname);
+		g_free (fname);
+		return quoted;
+	}
+}
